# Pdfcrowd API - Python client library

The Pdfcrowd API lets you easily convert between HTML, PDF and various image
formats in your Python applications.

To use the API, you need an account on
[http://pdfcrowd.com](https://pdfcrowd.com). If you don't have one, you
can sign up [here](https://pdfcrowd.com/pricing/api/).

## Installation

The library runs on Python 2 and 3. It can be installed from
[pypi](http://pypi.python.org/pypi/pdfcrowd/):

    pip install pdfcrowd

Or you can download/clone the client and run

    git clone https://github.com/pdfcrowd/pdfcrowd-python.git
    cd pdfcrowd-python/
    python setup.py install

## Learn more

* API Home:  <https://pdfcrowd.com/doc/api/>
* API Reference:  <https://pdfcrowd.com/doc/api/html-to-pdf/python/>
* Interactive API Playground:
  * Python: <https://pdfcrowd.com/playground/html-to-pdf/?lang=python>
  * Django: <https://pdfcrowd.com/playground/html-to-pdf/?lang=wf-django>
  * Flask: <https://pdfcrowd.com/playground/html-to-pdf/?lang=wf-flask>

## License

This client library is licensed under the MIT License.
